@extends('layouts.app')
@section('page-title', 'Регистрация входящей посылки')
@section('content')
    <div class="py-5 text-center">
        <img class="d-block mx-auto mb-4" src="{{ url('images/ship/box-png.png') }}" alt="" width="72" height="72">
        <h2>Регистрация посылки</h2>
        <p class="lead">Тут вам необходимо заполнить данные о товаре который вы заказали в магазине США и которых придет на наш склад в США,
        для дальнейшей консолидации и отправки в Ташкент</p>
    </div>

    <div class="row">
        <div class="col-md-12 mb-4">

            <form action="{{ url('/packages/register') }}" method="POST" class="needs-validation border border-success bg-white p-5" novalidate>

                {{ csrf_field() }}

                <h4 class="d-flex justify-content-between align-items-center mb-3">
                    <span class="text-muted">Регистрация новой входящей посылки</span>
                </h4>

                <div class="row">
                    <div class="col-md-6 mb-3">
                        <label for="market_link">Ссылка на магазин в США</label>
                        <input type="text" class="form-control" id="market_link" name="market_link" placeholder="" value="" required>
                        <div class="invalid-feedback">
                            Обязательное поле.
                        </div>
                    </div>
                    <div class="col-md-6 mb-3">
                        <label for="track_number">Трек номер посылки</label>
                        <input type="text" class="form-control" id="track_number" name="track_number" placeholder="" value="" required>
                        <div class="invalid-feedback">
                            Обязательное поле.
                        </div>
                    </div>
                </div>

                <div class="mb-3">
                    <label for="package_name">Название посылки</label>
                    <input type="text" class="form-control" name="package_name" id="package_name">
                    <div class="invalid-feedback">
                        Пожалуйста введите название посылки
                    </div>
                </div>

                <div class="mb-3">
                    <label for="comment">Комментарий к посылке</label>
                    <input type="text" class="form-control" name="comment" id="comment" >
                </div>

                Декларация посылки
                <table class="table table-bordered table-hover table-sm mt-2" id="table_package">
                    <thead class="thead-light">
                    <tr class="d-flex">
                        <th class="col-1 text-center">№</th>
                        <th class="col-3">Название товара</th>
                        <th class="col-2">Количество</th>
                        <th class="col-2">Цена</th>
                        <th class="col-2">Вес</th>
                        <th class="col-1">Стоим...</th>
                        <th class="col-1"></th>
                    </tr>
                    </thead>
                    <tbody>
                    <tr class="d-flex">
                        <td class="text-center col-1 counter_number">1</td>
                        <td class="col-3">
                            <input type="text" name="item_name[]" class="form-control form-control-sm" required />
                        </td>
                        <td class="col-2">
                            <div class="input-group input-group-sm">
                                <div class="input-group-prepend input-group-sm">
                                    <span class="input-group-text">шт</span>
                                </div>
                                <input type="number" name="amount[]" class="form-control form-control-sm count" id="" value="1" required>
                                <div class="invalid-feedback" >
                                    Укажите количество единиц товара
                                </div>
                            </div>
                        </td>
                        <td class="col-2">
                            <div class="input-group input-group-sm">
                                <div class="input-group-prepend input-group-sm">
                                    <span class="input-group-text">$</span>
                                </div>
                                <input type="number" name="price[]" class="form-control form-control-sm cost" id="" placeholder="Username" value="2" required>
                                <div class="invalid-feedback" >
                                    Укажите стоимость за единицу товара
                                </div>
                            </div>
                        </td>
                        <td class="col-2">
                            <div class="input-group input-group-sm">
                                <div class="input-group-prepend input-group-sm">
                                    <span class="input-group-text">кг</span>
                                </div>
                                <input type="number" step="0.1" name="weight[]" class="form-control form-control-sm" id="username" placeholder="Username" value="0.3" required>
                                <div class="invalid-feedback" >
                                    Your username is required.
                                </div>
                            </div>
                        </td>
                        <td class="text-center col-1">
                            <span class="cost_per_stuff">$2</span>
                        </td>
                        <td class="col-1 text-center">
                            <a href="#" class="btn btn-sm btn-outline-danger btn-round button-delete">X</a>
                        </td>
                    </tr>
                    </tbody>
                </table>

                <div class="row">
                    <div class="col-6">
                        <a href="#" class="btn btn-outline-success btn-sm" id="add_new_packet"><strong>+ Добавить посылку</strong></a>
                    </div>
                    <div class="col-6 text-right">
                        Итоговая сумма в декларации: <strong><span class="text-success" id="total_price">$2</span></strong>
                    </div>
                </div>

                <hr class="mb-4">
                <div class="custom-control custom-checkbox">
                    <input type="checkbox" class="custom-control-input" id="same-address">
                    <label class="custom-control-label" for="same-address">Сделать фотографию посылки</label>
                </div>

                <hr class="mb-4">
                <button class="btn btn-success btn-lg btn-block" type="submit">Зарегистрировать</button>
            </form>
        </div>
    </div>
@endsection
@section('custom_script')
    <script>
        var counter = 1;

        function count_total_cost()
        {
            var total_sum = 0;
            $('#table_package').find('tbody > tr').each(function (i, el) {
                var cost = $(this).find('.cost_per_stuff').text().slice(1);
                total_sum += parseInt(cost);
            });
            $('#total_price').text('$' + total_sum);
        }

        function recount_order()
        {
            counter = 1;
            $('.counter_number').each(function () {
                $(this).html(counter);
                counter += 1;
            });
        }

        $('#table_package').on('keyup, focusout', '.count, .cost', function () {
            $(this).parent().parent().parent().find('.cost_per_stuff').text('$' +
                $(this).parent().parent().parent().find('.count').val() * $(this).parent().parent().parent().find('.cost').val()
            );
            count_total_cost();
        });

        $('#table_package').on('click', '.button-delete', function (e) {
            e.preventDefault();
            $(this).parent().parent().remove();
            count_total_cost();
            recount_order();
        });


        $('#add_new_packet').click(function (e) {
            e.preventDefault();
            counter += 1;
            $('#table_package > tbody:last-child').append('<tr class="d-flex">\n' +
                '                        <td class="text-center col-1 counter_number">' + counter + '</td>\n' +
                '                        <td class="col-3">\n' +
                '                            <input type="text" name="item_name[]" class="form-control form-control-sm" required />\n' +
                '                        </td>\n' +
                '                        <td class="col-2">\n' +
                '                            <div class="input-group input-group-sm">\n' +
                '                                <div class="input-group-prepend input-group-sm">\n' +
                '                                    <span class="input-group-text">шт</span>\n' +
                '                                </div>\n' +
                '                                <input type="number" name="amount[]" class="form-control form-control-sm count" id="" value="1" required>\n' +
                '                                <div class="invalid-feedback" >\n' +
                '                                    Укажите количество единиц товара\n' +
                '                                </div>\n' +
                '                            </div>\n' +
                '                        </td>\n' +
                '                        <td class="col-2">\n' +
                '                            <div class="input-group input-group-sm">\n' +
                '                                <div class="input-group-prepend input-group-sm">\n' +
                '                                    <span class="input-group-text">$</span>\n' +
                '                                </div>\n' +
                '                                <input type="number" name="price[]" class="form-control form-control-sm cost" id="" placeholder="Username" value="2" required>\n' +
                '                                <div class="invalid-feedback" >\n' +
                '                                    Укажите стоимость за единицу товара\n' +
                '                                </div>\n' +
                '                            </div>\n' +
                '                        </td>\n' +
                '                        <td class="col-2">\n' +
                '                            <div class="input-group input-group-sm">\n' +
                '                                <div class="input-group-prepend input-group-sm">\n' +
                '                                    <span class="input-group-text">кг</span>\n' +
                '                                </div>\n' +
                '                                <input type="number" step="0.1" name="weight[]" class="form-control form-control-sm" id="username" placeholder="Username" value="0.3" required>\n' +
                '                                <div class="invalid-feedback" >\n' +
                '                                    Your username is required.\n' +
                '                                </div>\n' +
                '                            </div>\n' +
                '                        </td>\n' +
                '                        <td class="text-center col-1">\n' +
                '                            <span class="cost_per_stuff">$2</span>\n' +
                '                        </td>\n' +
                '                        <td class="col-1 text-center">\n' +
                '                            <a href="#" class="btn btn-sm btn-outline-danger btn-round button-delete">X</a>\n' +
                '                        </td>\n' +
                '                    </tr>');

            count_total_cost();
            recount_order();
        });
    </script>
@endsection